@@ -7,9 +7,13 @@
 #ifndef PLASMA_NM_NETWORK_MODEL_H
 #define PLASMA_NM_NETWORK_MODEL_H
 
+#include "plasmanm_internal_export.h"
+
 #include <QAbstractListModel>
 #include <QQueue>
 
+#include <qqmlregistration.h>
+
 #include "networkitemslist.h"
 
 #include <NetworkManagerQt/Manager>
@@ -19,9 +23,10 @@
 
 #include <ModemManagerQt/Modem>
 
-class Q_DECL_EXPORT NetworkModel : public QAbstractListModel
+class PLASMANM_INTERNAL_EXPORT NetworkModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
 public:
     // Delay model updates to prevent jumping password entry in the applet.
     // This is an aggregate property, which is true whenever any of model items is true.
